@@ -1,5 +1,7 @@
 package Validator::Custom::HTMLForm;
 
+our $VERSION = '0.0611';
+
 use warnings;
 use strict;
 
@@ -7,17 +9,21 @@ use base 'Validator::Custom';
 
 use Validator::Custom::HTMLForm::Constraints;
 
-__PACKAGE__->register_constraint(
-    email             => \&Validator::Custom::HTMLForm::Constraints::email,
-    email_mx          => \&Validator::Custom::HTMLForm::Constraints::email_mx,
-    email_loose       => \&Validator::Custom::HTMLForm::Constraints::email_loose,
-    email_loose_mx    => \&Validator::Custom::HTMLForm::Constraints::email_loose_mx,
-    date              => \&Validator::Custom::HTMLForm::Constraints::date,
-    time              => \&Validator::Custom::HTMLForm::Constraints::time,
-    datetime          => \&Validator::Custom::HTMLForm::Constraints::datetime,
-    datetime_format   => \&Validator::Custom::HTMLForm::Constraints::datetime_format,
-    datetime_strptime => \&Validator::Custom::HTMLForm::Constraints::datetime_strptime,
-);
+sub new {
+    my $self = shift->SUPER::new(@_);
+    $self->register_constraint(
+        email             => \&Validator::Custom::HTMLForm::Constraints::email,
+        email_mx          => \&Validator::Custom::HTMLForm::Constraints::email_mx,
+        email_loose       => \&Validator::Custom::HTMLForm::Constraints::email_loose,
+        email_loose_mx    => \&Validator::Custom::HTMLForm::Constraints::email_loose_mx,
+        date              => \&Validator::Custom::HTMLForm::Constraints::date,
+        time              => \&Validator::Custom::HTMLForm::Constraints::time,
+        datetime          => \&Validator::Custom::HTMLForm::Constraints::datetime,
+        datetime_format   => \&Validator::Custom::HTMLForm::Constraints::datetime_format,
+        datetime_strptime => \&Validator::Custom::HTMLForm::Constraints::datetime_strptime,
+    );
+    return $self;
+}
 
 1;
 
@@ -25,10 +31,6 @@ __PACKAGE__->register_constraint(
 
 Validator::Custom::HTMLForm - HTML Form Validator
 
-=cut
-
-our $VERSION = '0.0610';
-
 =head1 SYNOPSIS
 
     use Validator::Custom::HTMLForm;
